@@ -1,6 +1,6 @@
 package Net::Riak::Bucket;
 BEGIN {
-  $Net::Riak::Bucket::VERSION = '0.11';
+  $Net::Riak::Bucket::VERSION = '0.13';
 }
 
 # ABSTRACT: Access and change information about a Riak bucket
@@ -68,6 +68,15 @@ sub get {
     $obj;
 }
 
+sub delete_object {
+    my ($self, $key) = @_;
+    Net::Riak::Object->new(
+        client => $self->client,
+        bucket => $self,
+        key    => $key
+    )->delete;
+}
+
 sub set_property {
     my ($self, $key, $value) = @_;
     $self->set_properties({$key => $value});
@@ -138,13 +147,14 @@ sub set_properties {
 
 sub new_object {
     my ($self, $key, $data, @args) = @_;
-    my $object = Net::Riak::Object->new(
-        key    => $key,
+    my %opts = (
         data   => $data,
         bucket => $self,
         client => $self->client,
         @args,
     );
+    $opts{key} = $key if defined $key;
+    my $object = Net::Riak::Object->new(%opts);
     $object;
 }
 
@@ -160,7 +170,7 @@ Net::Riak::Bucket - Access and change information about a Riak bucket
 
 =head1 VERSION
 
-version 0.11
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -174,6 +184,8 @@ version 0.11
     my $obj2 = $bucket->new_object('foo2', {...});
     $object->store;
 
+    $bucket->delete_object($key);
+
 =head1 DESCRIPTION
 
 The L<Net::Riak::Bucket> object allows you to access and change information about a Riak bucket, and provides methods to create or retrieve objects within the bucket.
@@ -218,12 +230,20 @@ DW value setting for this client (default 2)
 
 Create a new L<Net::Riak::Object> object. Additional Object constructor arguments can be passed after $data. If $data is a reference and no explicit Object content_type is given in @args, the data will be serialised and stored as JSON.
 
+If $key is passed as C<undef> then an autogenerated key will be provided by Riak.
+
 =item get
 
     my $obj = $bucket->get($key, [$r]);
 
 Retrieve an object from Riak.
 
+=item delete_object
+
+    $bucket->delete_object($key);
+
+Delete an object by key
+
 =item n_val
 
     my $n_val = $bucket->n_val;
@@ -301,7 +321,7 @@ franck cuny <franck@lumberjaph.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by linkfluence.
+This software is copyright (c) 2011 by linkfluence.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
