@@ -1,6 +1,6 @@
 package Net::Riak::Client;
 BEGIN {
-  $Net::Riak::Client::VERSION = '0.11';
+  $Net::Riak::Client::VERSION = '0.13';
 }
 
 use Moose;
@@ -41,6 +41,12 @@ has http_response => (
     handles => ['is_success']
 );
 
+has ua_timeout => (
+    is  => 'rw',
+    isa => 'Int',
+    default => 3
+);
+
 with 'Net::Riak::Role::UserAgent';
 with qw/
   Net::Riak::Role::REST
@@ -71,7 +77,7 @@ Net::Riak::Client
 
 =head1 VERSION
 
-version 0.11
+version 0.13
 
 =head1 AUTHOR
 
@@ -79,7 +85,7 @@ franck cuny <franck@lumberjaph.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by linkfluence.
+This software is copyright (c) 2011 by linkfluence.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
