@@ -1,12 +1,17 @@
 package Net::Riak::Role::UserAgent;
 BEGIN {
-  $Net::Riak::Role::UserAgent::VERSION = '0.11';
+  $Net::Riak::Role::UserAgent::VERSION = '0.13';
 }
 
 # ABSTRACT: useragent for Net::Riak
 
 use Moose::Role;
 use LWP::UserAgent;
+use LWP::ConnCache;
+
+our $CONN_CACHE;
+
+sub connection_cache { $CONN_CACHE ||= LWP::ConnCache->new }
 
 has useragent => (
     is      => 'rw',
@@ -21,7 +26,12 @@ has useragent => (
         $opts{MaxLineLength} = 65_536;
         @LWP::Protocol::http::EXTRA_SOCK_OPTS = %opts;
 
-        my $ua = LWP::UserAgent->new;
+        my $ua = LWP::UserAgent->new(
+            timeout => $self->ua_timeout
+        );
+
+        $ua->conn_cache(__PACKAGE__->connection_cache);
+
         $ua;
     }
 );
@@ -37,7 +47,7 @@ Net::Riak::Role::UserAgent - useragent for Net::Riak
 
 =head1 VERSION
 
-version 0.11
+version 0.13
 
 =head1 AUTHOR
 
@@ -45,7 +55,7 @@ franck cuny <franck@lumberjaph.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by linkfluence.
+This software is copyright (c) 2011 by linkfluence.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
